==> vtigercrm7.4.0.tar.gz: vtigercrm/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/PurchaseOrder.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
    'PurchaseOrder'                => 'Ordini d\'acquisto'          , 
	'SINGLE_PurchaseOrder'         => 'Ordini d\'acquisto'          , 
	'LBL_EXPORT_TO_PDF'            => 'Esporta in PDF'              , 
	'LBL_SEND_MAIL_PDF'            => 'Invia Email con PDF'         , 
	'LBL_ADD_RECORD'               => 'Add Purchase Order'          , 
	'LBL_RECORDS_LIST'             => 'Lista Ordini Acquisto'       , 
	'LBL_COPY_SHIPPING_ADDRESS'    => 'Copia Indirizzo di spedizione'       ,  
	'LBL_COPY_BILLING_ADDRESS'     => 'Copia indirizzo di fatturazione'        , 
	'LBL_PO_INFORMATION'           => 'Informazione Ordine di Acquisto ', 
	'PurchaseOrder No'             => 'Numero Ordine di Acquisto'   , 
	'Requisition No'               => 'Numero Richiesta'            , 
	'Tracking Number'              => 'Numero Tracking'             , 
	'Sales Commission'             => 'Commissioni Vendita'         , 
	'LBL_PAID'                     => 'Pagato'                        ,  
	'LBL_BALANCE'                  => 'Saldo'                     ,  S
	'Received Shipment'            => 'Spedizione Ricevuta'         ,
        'LBL_LIST_PRICE'               => 'Prezzo di listino',
        'List Price'                   => 'Prezzo di listino',
    'LBL_COPY_COMPANY_ADDRESS' => 'Copia Indirizzo Azienda',
    'LBL_COPY_ACCOUNT_ADDRESS' => 'Copia Indirizzo Organizzazione',  //TO review, Company vs Organization
	'LBL_SELECT_ADDRESS_OPTION' => 'Selezionare Indirizzo da copiare',
	'LBL_BILLING_ADDRESS' => 'Indirizzo di fatturazione',
	'LBL_COMPANY_ADDRESS' => 'Indirizzo Azienda',
	'LBL_ACCOUNT_ADDRESS' => 'Indirizzo Organizzazione',
	'LBL_VENDOR_ADDRESS' => 'Indirizzo Fornitore',
	'LBL_CONTACT_ADDRESS' => 'Indirizzo Contatto',

  'LBL_THIS' => 'Questo',
  'LBL_IS_DELETED_FROM_THE_SYSTEM_PLEASE_REMOVE_OR_REPLACE_THIS_ITEM' => 'viene eliminato dal sistema. Si prega di rimuovere o sostituire questo elemento',
  'LBL_THIS_LINE_ITEM_IS_DELETED_FROM_THE_SYSTEM_PLEASE_REMOVE_THIS_LINE_ITEM' => 'Questo elemento viene eliminato dal sistema, si prega di rimuovere questa riga di elementi',

);

$jsLanguageStrings = array(
    'JS_ORGANIZATION_NOT_FOUND'=> 'Organizzazione vuoto',
    'JS_ORGANIZATION_NOT_FOUND_MESSAGE'=> "Si prega di selezionare una organizzazione prima di copiare l'indirizzo",
	'JS_ACCOUNT_NOT_FOUND' => 'Organizzazione vuoto!!',
	'JS_ACCOUNT_NOT_FOUND_MESSAGE' =>  "Seleziona una organizzazione prima di copiare l'indirizzo",
	'JS_VENDOR_NOT_FOUND' => 'Fornitore vuoto', 
	'JS_VENDOR_NOT_FOUND_MESSAGE' => "Si prega di selezionare un fornitore prima di copiare l'indirizzo",
	'JS_CONTACT_NOT_FOUND' => 'Contatto vuoto', 
	'JS_CONTACT_NOT_FOUND_MESSAGE' =>  "Si prega di selezionare un contatto prima di copiare l'indirizzo",

  'JS_PLEASE_REMOVE_LINE_ITEM_THAT_IS_DELETED' => 'Si prega di rimuovere la riga di prodotto che viene eliminata',

);

==> vtigercrm8.4.0.tar.gz: vtigercrm/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/PurchaseOrder.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
    'PurchaseOrder'                => 'Ordini d\'acquisto'          , 
	'SINGLE_PurchaseOrder'         => 'Ordini d\'acquisto'          , 
	'LBL_EXPORT_TO_PDF'            => 'Esporta in PDF'              , 
	'LBL_SEND_MAIL_PDF'            => 'Invia Email con PDF'         , 
	'LBL_ADD_RECORD'               => 'Add Purchase Order'          , 
	'LBL_RECORDS_LIST'             => 'Lista Ordini Acquisto'       , 
	'LBL_COPY_SHIPPING_ADDRESS'    => 'Copia Indirizzo di spedizione'       ,  
	'LBL_COPY_BILLING_ADDRESS'     => 'Copia indirizzo di fatturazione'        , 
	'LBL_PO_INFORMATION'           => 'Informazione Ordine di Acquisto ', 
	'PurchaseOrder No'             => 'Numero Ordine di Acquisto'   , 
	'Requisition No'               => 'Numero Richiesta'            , 
	'Tracking Number'              => 'Numero Tracking'             , 
	'Sales Commission'             => 'Commissioni Vendita'         , 
	'LBL_PAID'                     => 'Pagato'                        ,  
	'LBL_BALANCE'                  => 'Saldo'                     ,
	'Received Shipment'            => 'Spedizione Ricevuta'         ,
        'LBL_LIST_PRICE'               => 'Prezzo di listino',
        'List Price'                   => 'Prezzo di listino',
    'LBL_COPY_COMPANY_ADDRESS' => 'Copia Indirizzo Azienda',
    'LBL_COPY_ACCOUNT_ADDRESS' => 'Copia Indirizzo Organizzazione',  //TO review, Company vs Organization
	'LBL_SELECT_ADDRESS_OPTION' => 'Selezionare Indirizzo da copiare',
	'LBL_BILLING_ADDRESS' => 'Indirizzo di fatturazione',
	'LBL_COMPANY_ADDRESS' => 'Indirizzo Azienda',
	'LBL_ACCOUNT_ADDRESS' => 'Indirizzo Organizzazione',
	'LBL_VENDOR_ADDRESS' => 'Indirizzo Fornitore',
	'LBL_CONTACT_ADDRESS' => 'Indirizzo Contatto',

  'LBL_THIS' => 'Questo',
  'LBL_IS_DELETED_FROM_THE_SYSTEM_PLEASE_REMOVE_OR_REPLACE_THIS_ITEM' => 'viene eliminato dal sistema. Si prega di rimuovere o sostituire questo elemento',
  'LBL_THIS_LINE_ITEM_IS_DELETED_FROM_THE_SYSTEM_PLEASE_REMOVE_THIS_LINE_ITEM' => 'Questo elemento viene eliminato dal sistema, si prega di rimuovere questa riga di elementi',

);

$jsLanguageStrings = array(
    'JS_ORGANIZATION_NOT_FOUND'=> 'Organizzazione vuoto',
    'JS_ORGANIZATION_NOT_FOUND_MESSAGE'=> "Si prega di selezionare una organizzazione prima di copiare l'indirizzo",
	'JS_ACCOUNT_NOT_FOUND' => 'Organizzazione vuoto!!',
	'JS_ACCOUNT_NOT_FOUND_MESSAGE' =>  "Seleziona una organizzazione prima di copiare l'indirizzo",
	'JS_VENDOR_NOT_FOUND' => 'Fornitore vuoto', 
	'JS_VENDOR_NOT_FOUND_MESSAGE' => "Si prega di selezionare un fornitore prima di copiare l'indirizzo",
	'JS_CONTACT_NOT_FOUND' => 'Contatto vuoto', 
	'JS_CONTACT_NOT_FOUND_MESSAGE' =>  "Si prega di selezionare un contatto prima di copiare l'indirizzo",

  'JS_PLEASE_REMOVE_LINE_ITEM_THAT_IS_DELETED' => 'Si prega di rimuovere la riga di prodotto che viene eliminata',

);
